==> fswiki-3.5.6.tbz: share/fswiki/plugin/bbs/BBS2.pm <==
###############################################################################
#
# <p>ǼƥեϤޤƤڡȤʤꡢڡ⥵ݡȤޤ</p>
# <pre>
# {{bbs2 ǼĤ̾,ɽ}}
# </pre>
# <p>
#   bbsץ饰Ȥΰ㤤ϣƤĤΥڡȤƺ졢
#   ɽ뤳ȤǤϻɽ뤿ᡢ
#   ˲ưԽɬפޤ
#   ɽά10鷺ɽޤ
# </p>
# <p>
#   ǥեȤǤϳƵֿѤΥȥեबϤޤ
#   no_commentץĤOFFˤ뤳ȤǤޤ
# </p>
# <pre>
# {{bbs2 ǼĤ̾,ɽ,no_comment}}
# </pre>
# <p>
#   reverse_commentץĤȳƵˤĤcommentץ饰
#   reverseץĤ뤳ȤǤȤɽ褦ˤʤޤ
# </p>
# <pre>
# {{bbs2 ǼĤ̾,ɽ,reverse_comment}}
# </pre>
# <p>
#   no_listץĤȵΰɽƥեɽޤ
#   ξbbs2listץ饰ȤäƵΰɽ뤳ȤǤޤ
# </p>
# <pre>
# {{bbs2 ǼĤ̾,no_list}}
# </pre>
#
###############################################################################
package plugin::bbs::BBS2;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# Ǽϥե
#==============================================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $name   = shift;
	my $once   = shift;
	my $option = shift;
	
	if($name eq ""){
		return &Util::paragraph_error("ǼĤ̾ꤵƤޤ");
	}
	if($once eq "" || !&Util::check_numeric($once)){
		$option = $once;
		$once   = 10;
	}
	
	my $cgi = $wiki->get_CGI;
	my $page = $cgi->param("page");
	
	# ϥե
	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/bbs.tmpl",
	                               die_on_bad_params=>0);
	
	# åѤʤΤ̾
	my $postname = '';
	unless($wiki->use_cache($page)){
		$postname = $cgi->cookie(-name=>'post_name');
		if($postname eq ''){
			my $login = $wiki->get_login_info();
			if(defined($login)){
				$postname = $login->{id};
			}
		}
	}
	$tmpl->param(NAME=>$postname);
	
	my $buf = "<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
	          $tmpl->output.
	          "<input type=\"hidden\" name=\"action\" value=\"BBS2\">\n".
	          "<input type=\"hidden\" name=\"bbsname\" value=\"".&Util::escapeHTML($name)."\">\n";
	
	if($option eq "no_comment"){
		$buf .="<input type=\"hidden\" name=\"option\" value=\"no_comment\">\n";
	} elsif($option eq "reverse_comment"){
		$buf .="<input type=\"hidden\" name=\"option\" value=\"reverse_comment\">\n";
	}
	
	$buf .= "</form>";
	
	# ΰϢno_listץ󤬤Ĥ줿ɽʤ
	if($option ne "no_list"){
		$buf .= $wiki->process_wiki("{{bbs2list $name,$once}}");
	}
	
	return $buf;
}

1;

==> fswiki-3.6.2_1.tbz: share/fswiki/plugin/bbs/BBS2.pm <==
###############################################################################
#
# <p>ǼƥեϤޤƤڡȤʤꡢڡ⥵ݡȤޤ</p>
# <pre>
# {{bbs2 ǼĤ̾,ɽ}}
# </pre>
# <p>
#   bbsץ饰Ȥΰ㤤ϣƤĤΥڡȤƺ졢
#   ɽ뤳ȤǤϻɽ뤿ᡢ
#   ˲ưԽɬפޤ
#   ɽά10鷺ɽޤ
# </p>
# <p>
#   ǥեȤǤϳƵֿѤΥȥեबϤޤ
#   no_commentץĤOFFˤ뤳ȤǤޤ
# </p>
# <pre>
# {{bbs2 ǼĤ̾,ɽ,no_comment}}
# </pre>
# <p>
#   reverse_commentץĤȳƵˤĤcommentץ饰
#   reverseץĤ뤳ȤǤȤɽ褦ˤʤޤ
# </p>
# <pre>
# {{bbs2 ǼĤ̾,ɽ,reverse_comment}}
# </pre>
# <p>
#   no_listץĤȵΰɽƥեɽޤ
#   ξbbs2listץ饰ȤäƵΰɽ뤳ȤǤޤ
# </p>
# <pre>
# {{bbs2 ǼĤ̾,no_list}}
# </pre>
#
###############################################################################
package plugin::bbs::BBS2;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# Ǽϥե
#==============================================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $name   = shift;
	my $once   = shift;
	my $option = shift;
	
	if($name eq ""){
		return &Util::paragraph_error("ǼĤ̾ꤵƤޤ");
	}
	if($once eq "" || !&Util::check_numeric($once)){
		$option = $once;
		$once   = 10;
	}
	
	my $cgi = $wiki->get_CGI;
	my $page = $cgi->param("page");
	
	# ϥե
	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/bbs.tmpl",
	                               die_on_bad_params=>0);
	
	# ̾
	my $postname = $cgi->cookie(-name=>'post_name');
	if($postname eq ''){
		my $login = $wiki->get_login_info();
		if(defined($login)){
			$postname = $login->{id};
		}
	}
	$tmpl->param(NAME=>$postname);
	
	my $buf = "<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
	          $tmpl->output.
	          "<input type=\"hidden\" name=\"action\" value=\"BBS2\">\n".
	          "<input type=\"hidden\" name=\"bbsname\" value=\"".&Util::escapeHTML($name)."\">\n";
	
	if($option eq "no_comment"){
		$buf .="<input type=\"hidden\" name=\"option\" value=\"no_comment\">\n";
	} elsif($option eq "reverse_comment"){
		$buf .="<input type=\"hidden\" name=\"option\" value=\"reverse_comment\">\n";
	}
	
	$buf .= "</form>";
	
	# ΰϢno_listץ󤬤Ĥ줿ɽʤ
	if($option ne "no_list"){
		$buf .= $wiki->process_wiki("{{bbs2list $name,$once}}");
	}
	
	return $buf;
}

1;
